pub struct NSZone { /* private fields */ }Available on crate feature
NSZone only.Expand description
A type used to identify and manage memory zones.
Zones are ignored on all newer platforms, you should very rarely need to
use this, but may be useful if you need to implement copyWithZone: or
allocWithZone:.