Type Definition objc2_foundation::NSAttributedStringKey
source · [−]pub type NSAttributedStringKey = NSString;Expand description
Attributes that you can apply to text in an attributed string.
pub type NSAttributedStringKey = NSString;Attributes that you can apply to text in an attributed string.